@@ -50,7 +50,7 @@ interface TextPacket {
 
 class AnsiUp
 {
-    VERSION = "4.0.3";
+    VERSION = "5.0.0";
 
     //
     // *** SEE README ON GITHUB FOR PUBLIC API ***
@@ -66,7 +66,6 @@ class AnsiUp
     private bold:boolean;
 
     private _use_classes:boolean;
-    private _escape_for_html;
 
     private _csi_regex:RegExp;
 
@@ -82,7 +81,6 @@ class AnsiUp
         // All construction occurs here
         this.setup_palettes();
         this._use_classes = false;
-        this._escape_for_html = true;
 
         this.bold = false;
         this.fg = this.bg = null;
@@ -102,16 +100,6 @@ class AnsiUp
         return this._use_classes;
     }
 
-    set escape_for_html(arg:boolean)
-    {
-        this._escape_for_html = arg;
-    }
-
-    get escape_for_html():boolean
-    {
-        return this._escape_for_html;
-    }
-
     set url_whitelist(arg:{})
     {
         this._url_whitelist = arg;
@@ -183,10 +171,12 @@ class AnsiUp
 
     private escape_txt_for_html(txt:string):string
     {
-      return txt.replace(/[&<>]/gm, (str) => {
-        if (str === "&") return "&amp;";
-        if (str === "<") return "&lt;";
-        if (str === ">") return "&gt;";
+      return txt.replace(/[&<>"']/gm, (str) => {
+        if (str === "&")  return "&amp;";
+        if (str === "<")  return "&lt;";
+        if (str === ">")  return "&gt;";
+        if (str === "\"") return "&quot;";
+        if (str === "'")  return "&#x27;";
       });
     }
 
@@ -631,8 +621,7 @@ class AnsiUp
         if (txt.length === 0)
             return txt;
 
-        if (this._escape_for_html)
-            txt = this.escape_txt_for_html(txt);
+        txt = this.escape_txt_for_html(txt);
 
         // If colors not set, default style is used
         if (!fragment.bold && fragment.fg === null && fragment.bg === null)
